# qwertyenv
Gym environments (Reinforcement Learning)

Black Jack (from RLBook2018)

Collect Coins (Chess like)

"Ensure Valid Action" Gym wrapper.

"Up/Down/Left/Right" Gym wrapper - relevant for example for the Collect Coins environment when the piece is a rock.

> pip install qwertyenv

Example usages for the Black Jack environment and for the Collect Coins environment can be found on github (the project's home).
